package com.gree.mall.manager.logic.material.worker;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.enums.material.PartsOrderFlagEnum;
import com.gree.mall.manager.enums.material.PartsRefTypeEnum;
import com.gree.mall.manager.enums.material.PartsRepairFlagEnum;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.WebsitPartsOldRefundManage;
import com.gree.mall.manager.plus.entity.WebsitPartsOldRefundManageItem;
import com.gree.mall.manager.plus.service.WebsitPartsOldRefundManageItemService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class OldRefundManageInnerLogic {

    private final CommonLogic commonLogic;
    private final WebsitPartsOldRefundManageItemService websitPartsOldRefundManageItemService;

    @Transactional(rollbackFor = Exception.class)
    public void submit(WebsitPartsOldRefundManage partsOldRefundManage) throws Exception {
        AdminUserCom adminUser = commonLogic.getAdminUser();
        if (!partsOldRefundManage.getFlag().equals(PartsOrderFlagEnum.SAVE.getKey())) {
            return;
        }

        DateTime curDate = DateUtil.date();
        partsOldRefundManage
                .setSettlementState(true)
                .setImportTime(curDate)
                .setFlag(partsOldRefundManage.getRepairFlag().equals(PartsRepairFlagEnum.INNER.getKey()) ? PartsOrderFlagEnum.AGREE.getKey() : PartsOrderFlagEnum.SUBMIT.getKey())
                .setSubmitBy(adminUser.getNickName())
                .setSubmitTime(curDate)
                .updateById();

        String refType = PartsRepairFlagEnum.INNER.getKey().equals(partsOldRefundManage.getRepairFlag()) ?
                PartsRefTypeEnum.OLD_REFUND.getKey() :
                PartsRefTypeEnum.OUTSIDE_TO_SALES.getKey();
        // 提交状态时 旧件库存减 临占件库存加
        List<WebsitPartsOldRefundManageItem> partsOldRefundManageItems = websitPartsOldRefundManageItemService.lambdaQuery()
                .eq(WebsitPartsOldRefundManageItem::getApplyNo, partsOldRefundManage.getApplyNo())
                .list();

//        List<WorkerStockDTO> workerStockDTOList = this.createWorkerStockDTO(partsOldRefundManage, partsOldRefundManageItems,
//                refType, PartsStockPartsAttrEnum.OLD.toString(), PartsStockPartsAttrEnum.TEMP_OLD.toString(), PartsExamineFlagEnum.SUBMIT.toString());
//        partsStockLogic.handleWorkerStock(workerStockDTOList);

//        this.insertPartsMessageTip(partsOldRefundManage, curDate);
    }
}
